@@ -327,20 +327,26 @@ class DialogueIsGreaterThanEN(SpecialCondition, ABC):
             return False
         i = state.v_pointer
         n_quota = 0
+        n_s_quota = 0
         n_word = 0
-        out = True
+        s_quota_result = True
+        quota_result = True
         while i >= 0:
             if self.symbols['all_quota'].match(state[i]):
                 n_quota += 1
+            if self.symbols['all_s_quota'].match(state[i]):
+                n_s_quota += 1
             if n_quota >= 2:
-                out = False
+                quota_result = False
+            if n_s_quota >= 2:
+                s_quota_result = False
             if self.word_pattern.match(state[i]):
                 n_word += 1
                 if n_word >= self.length:
                     break
             i -= 1
 
-        return out
+        return s_quota_result or quota_result
 
 
 class IsListQuotaEN(SpecialCondition):
@@ -463,7 +469,7 @@ class IsSenetnecDash(SpecialCondition):
     '''
 
     def __init__(self):
-        super(IsSenetnecDash, self).__init__('IsSenetnecDash',SYMBOLS_EN)
+        super(IsSenetnecDash, self).__init__('IsSenetnecDash', SYMBOLS_EN)
 
     def accept(self, state: StrSequence) -> bool:
         if self.symbols['dash'].match(state.current_value):
