@@ -262,14 +262,21 @@ class LongHandlerEN(Operation):
             if not self.space.match(state.current_value):
                 sub_len += 1
 
-            if self.is_next_with_space(state) and self.is_end_symbol(state) and self.not_in_white_list(
-                    state) and sub_len > self.min_sentence_length:
+            if self.is_next_with_space(state) and self.is_end_symbol(state) and self.not_in_white_list(state) and sub_len > self.min_sentence_length:
                 state.v_pointer = org_pointer
                 return i, True
 
-            if self.is_right_quota(state) and sub_len > self.min_sentence_length and self.is_dialogue_gt(state):
+            elif self.is_right_quota(state) and sub_len > self.min_sentence_length and self.is_dialogue_gt(state) and \
+                    (self.is_next_with_space(state) or state.v_pointer == state.length-1):
                 state.v_pointer = org_pointer
                 return min(i + 1, state.length - 1), True
+
+            elif self.is_s_quota_left(state) and sub_len > self.min_sentence_length and self.is_dialogue_gt(state) and \
+                    (self.is_next_with_space(state) or state.v_pointer == state.length-1):
+                state.v_pointer = org_pointer
+                return min(i + 1, state.length - 1), True
+            else:
+                continue
         else:
             state.v_pointer = org_pointer
             return -1, False
@@ -278,6 +285,8 @@ class LongHandlerEN(Operation):
         org_pointer = state.v_pointer
         for i in range(state.sentence_start + self.min_sentence_length * 2 - 1, org_pointer):
             state.v_pointer = i
+            state.update_quota()
+            state.update_barcket()
             if self.is_sentence_dash(state):
                 return i, True
         return -1, False
@@ -312,6 +321,13 @@ class LongHandlerEN(Operation):
         # self.pre_index = org_pointer
         self.pre_sentence_start = state.sentence_start
 
+    def is_s_quota_left(self, state):
+        if self.is_s_left(state):
+            return True
+        if self.is_s_en(state) and state.s_quota_en % 2 != 0:
+            return True
+        return False
+
 
 class EndState(Operation):
     def __init__(self, symbols: dict, name=None):
